# Generated by Django 4.2.17 on 2026-01-21 22:18

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("brevo_analytics", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="brevomessage",
            options={
                "ordering": ["-sent_at", "-sent_date", "subject"],
                "verbose_name": "Brevo Message",
                "verbose_name_plural": "Brevo Messages",
            },
        ),
        migrations.AddField(
            model_name="brevomessage",
            name="sent_at",
            field=models.DateTimeField(
                blank=True,
                db_index=True,
                help_text="Timestamp del primo messaggio inviato",
                null=True,
            ),
        ),
        migrations.AddIndex(
            model_name="brevomessage",
            index=models.Index(
                fields=["-sent_at"], name="brevo_messa_sent_at_1c1f09_idx"
            ),
        ),
    ]
