# Generated by Django 4.2.17 on 2026-01-22 00:05

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("brevo_analytics", "0003_rename_email_brevoemail_and_unique_constraint"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="brevoemail",
            options={
                "ordering": ["-sent_at"],
                "verbose_name": "Brevo Email",
                "verbose_name_plural": "Brevo Emails",
            },
        ),
        migrations.AddField(
            model_name="brevoemail",
            name="blacklist_info",
            field=models.JSONField(
                blank=True,
                help_text="Cached blacklist info from Brevo API: {reason, blocked_at, senders, checked_at}",
                null=True,
            ),
        ),
    ]
